Description Usage Arguments See Also Examples
If activity B occured, it should be preceded by activity A in the same case.
1 | precedence(activity_a, activity_b)
|
activity_a |
Activity A. A character vector of length one. This should be an activity of the event log supplied to 'check_rule'. |
activity_b |
Activity B. A character vector of length one. This should be an activity of the event log supplied to 'check_rule'. |
Other Declarative Rules: absent,
and, contains_between,
contains_exactly, contains,
ends, responded_existence,
response, starts,
succession, xor
1 2 3 4 5 6 7 8 | library(bupaR)
library(eventdataR)
# A MRI Scan should be preceeded by a Blood test.
patients %>%
check_rule(precedence("Blood test","MRI SCAN"))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.