Description Usage Arguments See Also Examples
If activity A is executed, it should be eventually followed by activity B.
1 | response(activity_a, activity_b)
|
activity_a |
Activity A. A character vector of length one. This should be an activity of the event log supplied to 'check_rule'. |
activity_b |
Activity B. A character vector of length one. This should be an activity of the event log supplied to 'check_rule'. |
Other Declarative Rules: absent,
and, contains_between,
contains_exactly, contains,
ends, precedence,
responded_existence, starts,
succession, xor
1 2 3 4 5 6 7 | library(bupaR)
library(eventdataR)
# A blood test should eventually be followed by Discuss Results
patients %>%
check_rule(response("Blood test","Discuss Results"))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.