Description Usage Arguments See Also Examples
If activity A happens, it should be eventually followed by activity B. If activity B happens, it should be preceded by activity A.
1 | succession(activity_a, activity_b)
|
activity_a |
Activity A. A character vector of length one. This should be an activity of the event log supplied to 'check_rule'. |
activity_b |
Activity B. A character vector of length one. This should be an activity of the event log supplied to 'check_rule'. |
Other Declarative Rules: absent,
and, contains_between,
contains_exactly, contains,
ends, precedence,
responded_existence,
response, starts,
xor
1 2 3 4 5 6 7 | library(bupaR)
library(eventdataR)
# Blood test should always happen before a MRI Scan,
# and both should happen when one of them happens.
patients %>%
check_rule(succession("Blood test","MRI SCAN"))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.