Description Usage Arguments See Also Examples
If activity A exists, Activity B should not exist, and vice versa.
1 | xor(activity_a, activity_b)
|
activity_a |
Activity A. A character vector of length one. This should be an activity of the event log supplied to 'check_rule'. |
activity_b |
Activity B. A character vector of length one. This should be an activity of the event log supplied to 'check_rule'. |
Other Declarative Rules: absent,
and, contains_between,
contains_exactly, contains,
ends, precedence,
responded_existence,
response, starts,
succession
1 2 3 4 5 6 | library(bupaR)
library(eventdataR)
# A patient should not receive both an X-Ray and MRI Scan
patients %>%
check_rule(xor("X-Ray","MRI SCAN"))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.